<?php
/*
Plugin Name: 123 Moderate Comment Notification
Plugin URI: http://schnurpsel.de/wordpress-plugins/123-moderate-comment-notification/
Description: Legt fest, wer über anstehende Kommentarmoderation informiert wird.
Author: Ingo Henze
Version: 0.11
Author URI: http://putzlowitsch.de/
*/ 

// Einstellungen für das Plugin

// Einstellungen laden
$plw123mcn_options = get_option( 'plw123mcn_options' );
// noch keine vorhanden, dann mit Default-Werten vorbelegen
if( !is_array( $plw123mcn_options ) ) {
	$plw123mcn_options = array(
		'notify_admin'  => true,	// Admin informieren
		'notify_author' => false, // zum Admin nur den Autor informieren, wenn er Kommentare moderieren darf
		'notify_mods'   => false  // alle informieren, die Kommentare moderieren dürfen, wenn der Autor es nicht darf
	);
}
// wenn vorhanden, gegebenenfalls fehlende mit Default-Werten vorbelegen
else {
	if( !array_key_exists( 'notify_admin', $plw123mcn_options ) )
		$plw123mcn_options['notify_admin'] = true;
	if( !array_key_exists( 'notify_author', $plw123mcn_options ) )
		$plw123mcn_options['notify_author'] = false;
	if( !array_key_exists( 'notify_mods', $plw123mcn_options ) )
		$plw123mcn_options['notify_mods'] = false;
}


// Da beim aktivieren des Plugins die originale wp_notify_moderator Funktion bereits geladen ist,
// würde der Fehler "Cannot redeclare wp_notify_moderator() ..." auftreten.
// Deshalb muß das Plugin hier erstmal beendet werde.
if( !function_exists( 'wp_notify_moderator' ) ) {

	// Codebasis ist die originale Funktion aus WP 2.5.1
	// Funktion wp_redirect
	/**
	 * wp_notify_moderator() - Notifies the moderator of the blog about a new comment that is awaiting approval
	 *
	 * @since 1.0
	 * @uses $wpdb
	 *
	 * @param int $comment_id Comment ID
	 * @return bool Always returns true
	 */
	function wp_notify_moderator($comment_id) {
		global $wpdb;
		global $plw123mcn_options;
		
		if( get_option( "moderation_notify" ) == 0 )
			return true;

		$comment = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->comments WHERE comment_ID=%d LIMIT 1", $comment_id));
		$post = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->posts WHERE ID=%d LIMIT 1", $comment->comment_post_ID));
		
		$notify_message = "";
		
		// NCM-Erweiterung
		$post_author = new WP_User( $post->post_author );
		$post_author_mod = $post_author->has_cap( 'moderate_comments' );
		
		
    $email_send_to = array();

		// der Admin soll alle Nachrichten bekommen
		if( $plw123mcn_options['notify_admin'] ) {
			$admin_email = get_option('admin_email');
			if( !in_array( $admin_email, $email_send_to ) ) { 
				$email_send_to[] = $admin_email;
			}	
		}	
		
		// der Postautor darf  Kommentare moderieren
		if( $post_author_mod && $plw123mcn_options['notify_author'] ) {
			$user_email = $post_author->user_email;
			if( !in_array( $user_email, $email_send_to ) ) { 
				$email_send_to[] = $user_email;
			}	
		}
		else {
		  if( $plw123mcn_options['notify_mods'] ) {
				// User mit der Berechtigung "Kommentar-Moderation" finden
				$users_of_blog = get_users_of_blog();
				foreach( (array) $users_of_blog as $b_user ) {
					$blog_user = new WP_User( $b_user->user_id );
					if( $blog_user ) 
						if( $blog_user->has_cap( 'moderate_comments' ) ) {
							$user_email = $blog_user->user_email;
							if( !in_array( $user_email, $email_send_to ) ) { 
								$email_send_to[] = $user_email;
							}							
						}
				}
			}
		}
		
		$email_count = count( $email_send_to );
		if( $email_count>0 ) {
		  if( $email_count>1 ) {
				$email_send = $email_count-1;
				if( $email_send == 1 )
				  $email_info = 'einen weiteren';
				else	
				  $email_info = "$email_send weitere";
				$notify_message .= "Hinweis: Diese Nachricht wurde auch an $email_info Kommentar-Moderatoren gesendet.\r\n";
			}
		}
		else
		  return true;
			
			
		$comment_author_domain = @gethostbyaddr($comment->comment_author_IP);
		$comments_waiting = $wpdb->get_var("SELECT count(comment_ID) FROM $wpdb->comments WHERE comment_approved = '0'");

		switch ($comment->comment_type)
		{
			case 'trackback':
				$notify_message .= sprintf( __('A new trackback on the post #%1$s "%2$s" is waiting for your approval'), $post->ID, $post->post_title ) . "\r\n";
				$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
				$notify_message .= sprintf( __('Website : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
				$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
				$notify_message .= __('Trackback excerpt: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
				break;
			case 'pingback':
				$notify_message .= sprintf( __('A new pingback on the post #%1$s "%2$s" is waiting for your approval'), $post->ID, $post->post_title ) . "\r\n";
				$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
				$notify_message .= sprintf( __('Website : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
				$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
				$notify_message .= __('Pingback excerpt: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
				break;
			default: //Comments
				$notify_message .= sprintf( __('A new comment on the post #%1$s "%2$s" is waiting for your approval'), $post->ID, $post->post_title ) . "\r\n";
				$notify_message .= get_permalink($comment->comment_post_ID) . "\r\n\r\n";
				$notify_message .= sprintf( __('Author : %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
				$notify_message .= sprintf( __('E-mail : %s'), $comment->comment_author_email ) . "\r\n";
				$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
				$notify_message .= sprintf( __('Whois  : http://ws.arin.net/cgi-bin/whois.pl?queryinput=%s'), $comment->comment_author_IP ) . "\r\n";
				$notify_message .= __('Comment: ') . "\r\n" . $comment->comment_content . "\r\n\r\n";
				break;
		}

		if( function_exists( 'admin_url' ) ) {
			$notify_message .= sprintf( __('Approve it: %s'),  admin_url("comment.php?action=mac&c=$comment_id") ) . "\r\n";
			$notify_message .= sprintf( __('Delete it: %s'), admin_url("comment.php?action=cdc&c=$comment_id") ) . "\r\n";
			$notify_message .= sprintf( __('Spam it: %s'), admin_url("comment.php?action=cdc&dt=spam&c=$comment_id") ) . "\r\n";

			$notify_message .= sprintf( __ngettext('Currently %s comment is waiting for approval. Please visit the moderation panel:',
		 		'Currently %s comments are waiting for approval. Please visit the moderation panel:', $comments_waiting), number_format_i18n($comments_waiting) ) . "\r\n";
			$notify_message .= admin_url("edit-comments.php?comment_status=moderated") . "\r\n";
		}	
		else {
			$notify_message .= sprintf( __('Approve it: %s'),  get_option('siteurl')."/wp-admin/comment.php?action=mac&c=$comment_id" ) . "\r\n";
			$notify_message .= sprintf( __('Delete it: %s'), get_option('siteurl')."/wp-admin/comment.php?action=cdc&c=$comment_id" ) . "\r\n";
			$notify_message .= sprintf( __('Spam it: %s'), get_option('siteurl')."/wp-admin/comment.php?action=cdc&dt=spam&c=$comment_id" ) . "\r\n";

			$strCommentsPending = sprintf( __ngettext('%s comment', '%s comments', $comments_waiting), $comments_waiting );
			$notify_message .= sprintf( __('Currently %s are waiting for approval. Please visit the moderation panel:'), $strCommentsPending ) . "\r\n";
			$notify_message .= get_option('siteurl') . "/wp-admin/edit-comments.php?comment_status=moderated\r\n";
		}
		
		$subject = sprintf( __('[%1$s] Please moderate: "%2$s"'), get_option('blogname'), $post->post_title );

		$notify_message = apply_filters('comment_moderation_text', $notify_message, $comment_id);
		$subject = apply_filters('comment_moderation_subject', $subject, $comment_id);

		// emails senden
		foreach( $email_send_to as $user_email ) {
		  @wp_mail( $user_email, $subject, $notify_message );
		}	
    if( function_exists( 'plw123_debugfile_write' ) )
		  plw123_debugfile_write( "Moderations E-Mail gesendet an: ".implode( ',', $email_send_to) );
		
		return true;
	}
}

// Admin-Panel
if( WP_ADMIN == true ) :
function plw123mcn_options_subpanel() {
	global $plw123mcn_options;

  if (isset($_POST['plw123mcn_update'])) {
	// Optionen
	$plw123mcn_options['notify_admin'] = isset($_POST['plw123mcn_opt_nadm']);
	$plw123mcn_options['notify_author'] = isset($_POST['plw123mcn_opt_naut']);
	$plw123mcn_options['notify_mods'] = isset($_POST['plw123mcn_opt_nmod']);
	update_option('plw123mcn_options', $plw123mcn_options );
	
    ?><div class="updated"><p><strong>Einstellungen wurden gespeichert.</strong></p></div>
	<?php
  }
	$plugindata = get_plugin_data( __FILE__, false, true );
	?>
	
<div class="wrap" style="height:100%">
  <form method="post" id="plw123mcn_optform" onsubmit="return createLists()">
    <h2><?php echo $plugindata['Title']; ?> Einstellungen</h2>
	<p>Plugin-Version <?php echo $plugindata['Version']; ?></p>
	<p><?php echo $plugindata['Description']; ?></p>
	<table class="editform form-table" style='vertical-align:baseline;'>
	<tr><th><label>Administrator: </label></th><td><input type="checkbox" name="plw123mcn_opt_nadm" value="1" <?php if($plw123mcn_options['notify_admin']) echo 'checked="checked"'; ?> /> Administrator immer informieren</td></tr>
	<tr><th><label>Autor: </label></th><td><input type="checkbox" name="plw123mcn_opt_naut" value="1" <?php if($plw123mcn_options['notify_author']) echo 'checked="checked"'; ?> /> nur den Autor informieren, wenn er selbst Kommentare moderieren darf</td></tr>
	<tr><th><label>Moderatoren: </label></th><td><input type="checkbox" name="plw123mcn_opt_nmod" value="1" <?php if($plw123mcn_options['notify_mods']) echo 'checked="checked"'; ?> /> alle informieren, die Kommentare moderieren dürfen, wenn der Autor selbst es nicht darf</td></tr>
	</table>

<div class="submit" style="clear:both;">
  <input type="submit" name="plw123mcn_update" value="Einstellungen speichern »" />
</div>
  </form>
 </div><?php
}

function plw123mcn_add_admin_panel() {
	if (function_exists('add_options_page')) {
		add_options_page('123 Mod-Comment Notification', '123 Mod-Comment Notification', 8, basename(__FILE__), 'plw123mcn_options_subpanel');
    }
 }

add_action( 'admin_menu', 'plw123mcn_add_admin_panel' );
endif; // WP_ADMIN == true

?>